pub struct LockOptions {
pub comment: Option<String>,
pub steal_lock: bool,
pub current_rev: Option<u64>,
}Expand description
Options for crate::RaSvnSession::lock.
Fields
comment: Option<String>Optional lock comment.
steal_lock: boolWhether to steal an existing lock.
current_rev: Option<u64>Optional revision the lock is expected to apply to.
Implementations
Sourceimpl LockOptions
impl LockOptions
Sourcepub fn with_comment(self, comment: impl Into<String>) -> Self
pub fn with_comment(self, comment: impl Into<String>) -> Self
Sets a lock comment.
Sourcepub fn steal_lock(self) -> Self
pub fn steal_lock(self) -> Self
Enables stealing an existing lock.
Sourcepub fn with_current_rev(self, current_rev: u64) -> Self
pub fn with_current_rev(self, current_rev: u64) -> Self
Sets a current revision constraint for the lock request.